# -*- coding: utf-8 -*-

from image_cropping import ImageCropWidget
from django.utils.translation import ugettext as _
from django import forms

from jmb.news.models import News, Category


class SearchNewsForm(forms.ModelForm):
    event_date__month = forms.ChoiceField(label=_("Month"), required=False)
    event_date__year = forms.ChoiceField(label=_("Year"), required=False)
    title__icontains = forms.CharField(label=_("Title"), required=False)
    full_description__icontains = forms.CharField(label=_("Tags"), required=False)
    obj = forms.CharField(initial="news", widget=forms.HiddenInput)

    def __init__(self, *args, **kwargs):
        super(SearchNewsForm, self).__init__(*args, **kwargs)

        self.fields['event_date__month'].choices = [('', '-' * 9)] + News.get_months()
        self.fields['event_date__year'].choices = [('', '-' * 4)] + News.get_years()
        self.fields['categories'].queryset = Category.objects.filter(status=1)

    class Meta:
        model = News
        fields = ('categories',)


class NewsAdminForm(forms.ModelForm):
    class Meta:
        widgets = {
            'big_image': ImageCropWidget,
        }


